==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_event.js <==
_me = frm_event.prototype;
function frm_event(){};

_me.__constructor = function() {
	var me = this;

	var aData;
	if (this._aValues.EVNCLASS == 'O')
        aData = {noRepeat:true};

	this._draw('frm_event', 'main',aData);
	this.__initForm('EVENT::EVENT');
};

_me.__loadItems = function() {
	var me = this;
	
	// TAB1
	var tab1 = this.maintab.tab1;
	tab1.X_TIMEINTERVAL._value(this._aValues);
	loadDataIntoForm(tab1,this._aValues);
	if (!this._aValues['EVN_ID']) {
		this.maintab.tab1.EVNSTATUS._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','event_show_as'));
		this.maintab.tab1.EVNSHARETYPE._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','event_sharing'));
	}
	
	//Copy contact name into window title
	tab1.EVNTITLE._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
			    sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
		    me._title('EVENT::EVENT');
	};
	tab1.EVNTITLE._onkeyup();
		
	// TAB2 (recurrence)
	if (this.maintab.tab2)
	this.maintab.tab2._onactive = function (bFirstTime) {
		if (bFirstTime) {
			var recurrence = shiftObject(me._aValues['RECURRENCES']);
			if (recurrence != null)
				this.X_REPEATING._value(recurrence);
			
			if (Is.Defined(me._aValues['EVNSTARTDATE'])) {
				var rawDate = parseJulianDate(me._aValues['EVNSTARTDATE']); 
				var date = new Date(rawDate.year, rawDate.month-1, rawDate.day);
				this.X_REPEATING._setDate(date);
			}
		}
	}

	// TAB3 (attendees)
	this.maintab.tab3._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['CONTACTS']))
			this.X_ATTENDEES._value(me._aValues['CONTACTS']);
	}
	
	// TAB4 (Reminders)
	this.maintab.tab4._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['REMINDERS']))
			this.X_REMINDERS._value(me._aValues['REMINDERS']);
	}
	
	// TAB5 (attachments)
	this.maintab.tab5._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['ATTACHMENTS']))
			this.X_ATTACHMENTS._value({'path': me._sAccountID+'/'+me._sFolderID+'/'+me._sItemID, 'values': me._aValues['ATTACHMENTS']});
		else
		if(me._aValues['PUSH_ATTACHMENTS'])
			this.X_ATTACHMENTS.__addItems(me._aValues['PUSH_ATTACHMENTS']);
	}

	if (me._aValues['PUSH_ATTACHMENTS'])
		this.maintab.tab5._active();
};

_me.__saveItems = function(aValues) {
	// TAB1
	aValues['values'] = arrConcat(aValues['values'], this.maintab.tab1.X_TIMEINTERVAL._value());

	// TAB2
	if (this.maintab.tab2 && this.maintab.tab2.X_REPEATING && !Is.Empty(addon = this.maintab.tab2.X_REPEATING._value()))
		aValues['RECURRENCES'] = [addon];

	// TAB3
	if (this.maintab.tab3.X_ATTENDEES && !Is.Empty(addon = this.maintab.tab3.X_ATTENDEES._value()))
		aValues['CONTACTS'] = addon;

	// TAB4
	if (this.maintab.tab4.X_REMINDERS && !Is.Empty(addon = this.maintab.tab4.X_REMINDERS._value()))
		aValues['REMINDERS'] = this.maintab.tab4.X_REMINDERS._value();

	// TAB5
	if (this.maintab.tab5.X_ATTACHMENTS && !Is.Empty(addon = this.maintab.tab5.X_ATTACHMENTS._value()))
		aValues['ATTACHMENTS'] = this.maintab.tab5.X_ATTACHMENTS._value();
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_event.js <==
_me = frm_event.prototype;
function frm_event(){};

_me.__constructor = function() {
	var me = this;

	var aData = {};
    if(!(aData.owner = this._aValues.EVNORGANIZER)){
		var tmpf = Path.split(this._sFolderID)[0];
	    if (dataSet.get('folders',[this._sAccountID,tmpf,'TYPE'])=='A')
			aData.owner = tmpf;
		else
		    aData.owner = this._sAccountID;
	}
	
	if (this._aValues.EVNCLASS == 'O')
        aData.noRepeat = true;

	this._draw('frm_event', 'main', aData);
	this.__initForm('EVENT::EVENT');
};

_me.__loadItems = function() {
	var me = this;
	
	// TAB1
	var tab1 = this.maintab.tab1;
	tab1.X_TIMEINTERVAL._value(this._aValues);
	loadDataIntoForm(tab1,this._aValues);
	if (!this._aValues['EVN_ID']) {
		this.maintab.tab1.EVNSTATUS._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','event_show_as'));
		this.maintab.tab1.EVNSHARETYPE._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','event_sharing'));
	}
	
	//Copy contact name into window title
	tab1.EVNTITLE._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
			    sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
			me._title('EVENT::EVENT');
	};
	tab1.EVNTITLE._onkeyup();

	// TAB2 (recurrence)
	if (this.maintab.tab2)
	this.maintab.tab2._onactive = function (bFirstTime) {
		if (bFirstTime) {
			var recurrence = shiftObject(me._aValues['RECURRENCES']);
			if (recurrence != null)
				this.X_REPEATING._value(recurrence);

			if (Is.Defined(me._aValues['EVNSTARTDATE'])) {
				var rawDate = parseJulianDate(me._aValues['EVNSTARTDATE']); 
				var date = new Date(rawDate.year, rawDate.month-1, rawDate.day);
				this.X_REPEATING._setDate(date);
			}
		}
	}

	// TAB3 (attendees)
	this.maintab.tab3._onactive = function (bFirstTime) {
		if (bFirstTime){
			if (Is.Defined(me._aValues['CONTACTS']))
				this.X_SCHEDULE._attendees(me._aValues['CONTACTS']);

			if (me._aValues['EVNFLAGS']&1)
				this.X_SCHEDULE.X_TIMETABLE.invitation._value(1);
			else
			if (me._aValues['EVNFLAGS']&2)
				this.X_SCHEDULE.X_TIMETABLE.invitation._disabled(true);
		}
		this.X_SCHEDULE._sync(me.maintab.tab1.X_TIMEINTERVAL);
	}

	// TAB4 (Reminders)
	this.maintab.tab4._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['REMINDERS']))
			this.X_REMINDERS._value(me._aValues['REMINDERS']);
	}
	
	// TAB5 (attachments)
	this.maintab.tab5._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['ATTACHMENTS']))
			this.X_ATTACHMENTS._value({'path': me._sAccountID+'/'+me._sFolderID+'/'+me._sItemID, 'values': me._aValues['ATTACHMENTS']});
		else
		if(me._aValues['PUSH_ATTACHMENTS'])
			this.X_ATTACHMENTS.__addItems(me._aValues['PUSH_ATTACHMENTS']);
	}

	if (me._aValues['PUSH_ATTACHMENTS'])
		this.maintab.tab5._active();
};

_me.__saveItems = function(aValues) {

	// TAB1
	aValues['values'] = arrConcat(aValues['values'], this.maintab.tab1.X_TIMEINTERVAL._value());
	
	// TAB2
	if (this.maintab.tab2 && this.maintab.tab2.X_REPEATING && !Is.Empty(addon = this.maintab.tab2.X_REPEATING._value()))
		aValues['RECURRENCES'] = [addon];

	// TAB3
	if (this.maintab.tab3.X_SCHEDULE){
		if (!Is.Empty(addon = this.maintab.tab3.X_SCHEDULE._attendees()))
			aValues['CONTACTS'] = addon;

		if (!this.maintab.tab3.X_SCHEDULE.X_TIMETABLE.invitation._disabled()){
			aValues['values'].EVNFLAGS = this.maintab.tab3.X_SCHEDULE.X_TIMETABLE.invitation._value()?1:'';
			//aValues['values'].EVNORGANIZER = this.__owner;
		}
	}

	// TAB4
	if (this.maintab.tab4.X_REMINDERS && !Is.Empty(addon = this.maintab.tab4.X_REMINDERS._value()))
		aValues['REMINDERS'] = this.maintab.tab4.X_REMINDERS._value();

	// TAB5
	if (this.maintab.tab5.X_ATTACHMENTS && !Is.Empty(addon = this.maintab.tab5.X_ATTACHMENTS._value()))
		aValues['ATTACHMENTS'] = this.maintab.tab5.X_ATTACHMENTS._value();
};
